# nr-common
[![Build Status](https://travis-ci.org/nitred/nr-common.svg?branch=master)](https://travis-ci.org/nitred/nr-common)

Common python functionalities aimed to be at least compatible with Python3.

#### Current Stable Version
```
0.1.3
```


# Installation

### pip
```
pip install nr-common
```


### Development Installation

* Clone the project.
* Install in Anaconda3 environment
```
$ conda env create --force -f dev_environment.yml
$ source activate nr-common
$ pip install -e .
```


# Test
To run the tests:
```
make test
```


# Examples
```
$ python examples/simple.py
```


# License
MIT
